#ifndef NT2_INCLUDE_CONSTANTS_THREEPIO_4_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THREEPIO_4_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/threepio_4.hpp>

#endif
